.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    mer 29 gen 2014 09:44:51 CET
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

============
 Appendixes
============

.. toctree::

   rules
   dedication
   development
